@@ -1,8 +1,8 @@
 /*
- *  SPDX-FileCopyrightText: 2013-2019 Andreas Cord-Landwehr <cordlandwehr@kde.org>
- *
- *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
- */
+    SPDX-FileCopyrightText: 2013-2019 Andreas Cord-Landwehr <cordlandwehr@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #ifndef CONTRIBUTORREPOSITORY_H
 #define CONTRIBUTORREPOSITORY_H
@@ -115,14 +115,6 @@ public:
      */
     std::shared_ptr<EditableCourseResource> addCourse(const QUrl &courseFile);
 
-    /**
-     * Adds course to resource manager. If the course's language is not registered, the language
-     * is registered by this method.
-     *
-     * \param resource the course resource to add to resource manager
-     */
-    std::shared_ptr<EditableCourseResource> addCourseResource(std::unique_ptr<EditableCourseResource> resource);
-
     /**
      * Remove course from resource manager. If the course is modified its changes are NOT
      * written. For writing changes, the Course::sync() method must be called directly.
@@ -158,8 +150,6 @@ public:
 Q_SIGNALS:
     void languageResourceAdded();
     void languageResourceAboutToBeAdded(std::shared_ptr<ILanguage>, int);
-    void languageResourceRemoved();
-    void languageResourceAboutToBeRemoved(int);
     void repositoryChanged();
     void skeletonAdded();
     void skeletonAboutToBeAdded(ICourse *, int);
