@@ -1,8 +1,8 @@
 /*
- *  SPDX-FileCopyrightText: 2015 Andreas Cord-Landwehr <cordlandwehr@kde.org>
- *
- *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
- */
+    SPDX-FileCopyrightText: 2015 Andreas Cord-Landwehr <cordlandwehr@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #ifndef MAINWINDOW_EDITOR_H
 #define MAINWINDOW_EDITOR_H
@@ -37,9 +37,6 @@ public Q_SLOTS:
     void save();
     void quit();
 
-Q_SIGNALS:
-    void modeChanged(bool);
-
 private:
     ContributorRepository *m_repository;
     EditorSession *m_editorSession;
